// Load data
d3.text(
  'https://gist.githubusercontent.com/RahulBelede/13d05d3379bdf5d826b41f49705b3eee/raw/9d77db0d69b1f59279c07c0f4d1b1a8981b89cd9/gistfile1.txt',
).then(function (text) {
  // Split the text into lines
  const lines = text.trim().split('\n');

  // Initialize an empty array to store the data
  const data = [];

  // Extract headers
  const headers = lines[0].split(',');

  // Extract data
  for (let i = 1; i < lines.length; i++) {
    const lineData = lines[i].split(',');
    const carType = lineData[0];
    const sales = lineData.slice(1).map(Number);
    data.push({ Car_Type: carType, Sales: sales });
  }

  // Setup SVG
  const margin = {
    top: 20,
    right: 20,
    bottom: 50,
    left: 50,
  };
  const width = 800 - margin.left - margin.right;
  const height = 400 - margin.top - margin.bottom;

  const svg = d3
    .select('svg')
    .attr('width', width + margin.left + margin.right)
    .attr('height', height + margin.top + margin.bottom)
    .append('g')
    .attr(
      'transform',
      'translate(' + margin.left + ',' + margin.top + ')',
    );

  // Set up scales
  const xScale = d3
    .scaleBand()
    .domain(data.map((d) => d.Car_Type))
    .range([0, width])
    .padding(0.1);

  const yScale = d3
    .scaleLinear()
    .domain([0, d3.max(data, (d) => d3.max(d.Sales))])
    .nice()
    .range([height, 0]);

  // Draw lines
  const line = d3
    .line()
    .x(
      (d, i) =>
        xScale(data[i].Car_Type) + xScale.bandwidth() / 2,
    )
    .y((d) => yScale(d))
    .curve(d3.curveMonotoneX);

  const colors = ['#1f77b4', '#ff7f0e', '#2ca02c']; // Colors for 2019, 2020, and 2021 sales

  const spacingFactor = 30; // Adjust this factor to increase/decrease spacing between year labels

  for (let i = 1; i < headers.length; i++) {
    svg
      .append('path')
      .datum(data.map((d) => d.Sales[i - 1]))
      .attr('fill', 'none')
      .attr('stroke', colors[i - 1])
      .attr('stroke-width', 2)
      .attr('d', line);

    // Add year number to end of each line with adjusted spacing
    svg
      .append('text')
      .attr(
        'x',
        width - 5 - (headers.length - i) * spacingFactor,
      ) // Adjust position based on the index of the year
      .attr('y', yScale(data[data.length - 1].Sales[i - 1])) // Position at the end of the last data point
      .attr('dy', '0.35em')
      .style('font-size', '12px')
      .style('fill', colors[i - 1])
      .attr('text-anchor', 'end')
      .text(headers[i]);
  }

  // Draw axes
  svg
    .append('g')
    .attr('transform', 'translate(0,' + height + ')')
    .call(d3.axisBottom(xScale));

  svg.append('g').call(d3.axisLeft(yScale));

  // Add x-axis label
  svg
    .append('text')
    .attr('x', width / 2)
    .attr('y', height + margin.top + 10)
    .attr('text-anchor', 'middle')
    .text('Car Type');

  // Add y-axis label
  svg
    .append('text')
    .attr('transform', 'rotate(-90)')
    .attr('x', -height / 2)
    .attr('y', -margin.left)
    .attr('dy', '1em')
    .attr('text-anchor', 'middle')
    .text('Sales');

  // Chart title
  svg
    .append('text')
    .attr('x', width / 2)
    .attr('y', 0 - margin.top / 2)
    .attr('text-anchor', 'middle')
    .style('font-size', '16px')
    .text('Car Sales by Type (2019-2021)');
});
